@@ -3,8 +3,6 @@ use alloc::fmt::{self, Debug, Display, Formatter};
 #[cfg(feature = "alloc")]
 use alloc::vec::Vec;
 
-#[cfg(feature = "heapless")]
-use heapless::consts::U2;
 #[cfg(feature = "heapless")]
 use heapless::Vec as HeaplessVec;
 
@@ -314,7 +312,7 @@ impl CRCu16 {
 impl CRCu16 {
     /// Get the current CRC value (it always returns a heapless vec instance with a length corresponding to the CRC bits). You can continue calling `digest` method even after getting a CRC value.
     #[inline]
-    pub fn get_crc_heapless_vec_le(&mut self) -> HeaplessVec<u8, U2> {
+    pub fn get_crc_heapless_vec_le(&mut self) -> HeaplessVec<u8, 2> {
         let crc = self.get_crc();
 
         let e = (self.bits as usize + 7) >> 3;
@@ -328,7 +326,7 @@ impl CRCu16 {
 
     /// Get the current CRC value (it always returns a heapless vec instance with a length corresponding to the CRC bits). You can continue calling `digest` method even after getting a CRC value.
     #[inline]
-    pub fn get_crc_heapless_vec_be(&mut self) -> HeaplessVec<u8, U2> {
+    pub fn get_crc_heapless_vec_be(&mut self) -> HeaplessVec<u8, 2> {
         let crc = self.get_crc();
 
         let e = (self.bits as usize + 7) >> 3;
@@ -341,7 +339,6 @@ impl CRCu16 {
     }
 }
 
-#[allow(clippy::unreadable_literal)]
 impl CRCu16 {
     /// |Check|Poly|Init|Ref|XorOut|
     /// |---|---|---|---|---|
